@@ -1,6 +1,6 @@
 /*
  * static char *rcsid_client_types_h =
- *   "$Id: client-types.h,v 1.9 2005/09/21 13:04:59 qal21 Exp $";
+ *   "$Id: client-types.h 4963 2006-09-21 05:50:22Z mwedel $";
  */
 /*
     Crossfire client, a client program for the crossfire program.
@@ -76,9 +76,13 @@ typedef signed char     sint8;
 #if SIZEOF_LONG == 8
 typedef unsigned long       uint64;
 typedef signed long         sint64;
+#define FMT64               "ld"
+#define FMT64U              "ld"
 #elif SIZEOF_LONG_LONG == 8
 typedef unsigned long long      uint64;
 typedef signed long long        sint64;
+#define FMT64               "lld"
+#define FMT64U              "lld"
 #else
 #error do not know how to get a 64 bit value on this system.
 #error correct and send mail to crossfire-devel on how to do this.
@@ -95,6 +99,8 @@ typedef unsigned __int16    uint16;
 typedef signed __int16      sint16;
 typedef unsigned char     uint8;
 typedef signed char       sint8;
+#define FMT64               "I64d"
+#define FMT64U              "I64u"
 
 #endif
 
