@@ -1,5 +1,5 @@
 const char *rcsid_common_client_c =
-    "$Id: client.c,v 1.34 2006/05/21 10:32:55 akirschbaum Exp $";
+    "$Id: client.c 5076 2006-11-04 08:15:16Z mwedel $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -40,16 +40,27 @@ const char *rcsid_common_client_c =
  */
 
 
+#ifdef WIN32
+#include <windows.h>
+#define usleep(x) Sleep((x)/1000)
+#endif
 #include <client.h>
 #include <external.h>
 #include <errno.h>
 #include <script.h>
+#include <ctype.h>
 
 #include "mapdata.h"
 
 /* actually declare the globals */
 
-char *server=SERVER,*client_libdir=NULL,*meta_server=META_SERVER;
+#ifdef SERVER
+char *server=SERVER;
+#else
+char *server=NULL;
+#endif
+
+char *client_libdir=NULL,*meta_server=META_SERVER;
 char *image_file="", *sound_server="cfsndserv";
 char *skill_names[MAX_SKILL];
 
@@ -58,6 +69,9 @@ int meta_port=META_PORT, want_skill_exp=0,
     maxfd,map1cmd=0,metaserver_on=METASERVER;
 uint32	tick=0;
 
+uint16	exp_table_max=0;
+uint64	*exp_table=NULL;
+
 FILE *fpin,*fpout;
 Client_Player cpl;
 ClientSocket csocket;
@@ -127,7 +141,7 @@ struct CmdMapping commands[] = {
     { "ExtendedInfoSet", (CmdProc)ExtendedInfoSetCmd, NODATA},
 
     { "query", (CmdProc)handle_query, ASCII},
-    { "replyinfo", (CmdProc)ReplyInfoCmd, ASCII},
+    { "replyinfo", ReplyInfoCmd, ASCII},
     { "ExtendedTextSet", (CmdProc)SinkCmd, NODATA},
 };
 
@@ -159,7 +173,6 @@ void DoClient(ClientSocket *csocket)
 	    data++;
 	}
         len = csocket->inbuf.len - (data - csocket->inbuf.buf);
-	LOG(0,"Common::DoClient","Command:%s (%d)",csocket->inbuf.buf+2, len);
 	for(i=0;i < NCOMMANDS;i++) {
 	    if (strcmp((char*)csocket->inbuf.buf+2,commands[i].cmdname)==0) {
 		    script_watch((char*)csocket->inbuf.buf+2,data,len,commands[i].cmdformat);
@@ -174,7 +187,9 @@ void DoClient(ClientSocket *csocket)
     }
 }
 
-#ifndef WIN32
+#ifdef WIN32
+#define socklen_t int
+#else
 #include <netdb.h>
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -188,7 +203,8 @@ void DoClient(ClientSocket *csocket)
 
 int init_connection(char *host, int port)
 {
-    int fd = -1, oldbufsize, newbufsize=65535, buflen=sizeof(int);
+    int fd = -1, oldbufsize, newbufsize=65535;
+    socklen_t buflen=sizeof(int);
 #if !HAVE_GETADDRINFO || WIN32
     struct sockaddr_in insock;
     struct protoent *protox;
@@ -258,8 +274,7 @@ int init_connection(char *host, int port)
 	return -1;
 #endif
 
-    if (csocket.servername != NULL)
-        free(csocket.servername);
+    free(csocket.servername);
     csocket.servername = malloc(sizeof(char)*(strlen(host)+1));
     strcpy(csocket.servername, host);
 
@@ -356,6 +371,9 @@ void negotiate_connection(int sound)
 		    want_config[CONFIG_LIGHTING]?1:0, face_info.faceset,
 		    want_config[CONFIG_CACHE]);
 
+    /* We can do this right now also - isn't any reason to wait */
+    cs_print_string(csocket.fd,"requestinfo exp_table");
+
     use_config[CONFIG_MAPHEIGHT]=want_config[CONFIG_MAPHEIGHT];
     use_config[CONFIG_MAPWIDTH]=want_config[CONFIG_MAPWIDTH];
     mapdata_set_size(use_config[CONFIG_MAPWIDTH], use_config[CONFIG_MAPHEIGHT]);
