@@ -1,11 +1,11 @@
 /*
  * static char *rcsid_external_h =
- *   "$Id: external.h,v 1.12 2006/02/16 22:32:45 akirschbaum Exp $";
+ *   "$Id: external.h 4963 2006-09-21 05:50:22Z mwedel $";
  */
 /*
     Crossfire client, a client program for the crossfire program.
 
-    Copyright (C) 2001 Mark Wedel & Crossfire Development Team
+    Copyright (C) 2001,2006 Mark Wedel & Crossfire Development Team
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -57,6 +57,7 @@ extern int get_info_width(void);
 /* Stats related commands */
 extern void draw_stats(int redraw);
 extern void draw_message_window(int redraw);
+
 /* this should really just set a field in the stats, and let the
  * client figure the new weight limit out
  */
@@ -85,3 +86,5 @@ extern void unbind_key(const char *params);
 extern void save_winpos(void);
 extern void save_defaults(void);
 extern void command_show(const char *params);
+extern void client_tick(uint32 tick);
+extern void cleanup_connection();
