@@ -1,5 +1,5 @@
 const char *rcsid_common_init_c =
-    "$Id: init.c,v 1.31 2006/05/15 05:57:43 mwedel Exp $";
+    "$Id: init.c 5076 2006-11-04 08:15:16Z mwedel $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -26,6 +26,9 @@ const char *rcsid_common_init_c =
  * the I_IMAGE and I_ARCH commands.
  */
 
+#ifdef WIN32
+#define srandom(x) srand(x)
+#endif
 #include <client.h>
 #include "p_cmd.h" /* init_commands() */
 
@@ -49,7 +52,7 @@ NULL, "download_all_images", "echo_bindings",
 
 sint16 want_config[CONFIG_NUMS], use_config[CONFIG_NUMS];
 
-#define TEST_FREE_AND_CLEAR(xyz) {if (xyz) { free(xyz); xyz=NULL; } }
+#define FREE_AND_CLEAR(xyz) { free(xyz); xyz=NULL; }
 
 void VersionCmd(char *data, int len)
 {
@@ -107,6 +110,12 @@ void init_client_vars()
 	client_libdir=CLIENT_LIBDIR;
 #endif
 
+    if (exp_table) {
+	free(exp_table);
+	exp_table=NULL;
+    }
+    exp_table_max=0;
+
     cpl.count_left = 0;
     cpl.container = NULL;
     memset(&cpl.stats,0, sizeof(Stats));
@@ -169,7 +178,7 @@ void init_client_vars()
     want_config[CONFIG_FOGWAR] = TRUE;
     want_config[CONFIG_ICONSCALE] = 100;
     want_config[CONFIG_MAPSCALE] = 100;
-    want_config[CONFIG_POPUPS] = TRUE;
+    want_config[CONFIG_POPUPS] = FALSE;
     want_config[CONFIG_DISPLAYMODE] = CFG_DM_PIXMAP;
     want_config[CONFIG_SHOWICON] = FALSE;
     want_config[CONFIG_TOOLTIPS] = TRUE;
@@ -277,15 +286,15 @@ void reset_client_vars()
     face_info.cache_misses=0;
     face_info.have_faceset_info=0;
     for (i=0; i<MAX_FACE_SETS; i++) {
-	TEST_FREE_AND_CLEAR(face_info.facesets[i].prefix);
-	TEST_FREE_AND_CLEAR(face_info.facesets[i].fullname);
+	FREE_AND_CLEAR(face_info.facesets[i].prefix);
+	FREE_AND_CLEAR(face_info.facesets[i].fullname);
 	face_info.facesets[i].fallback = 0;
-	TEST_FREE_AND_CLEAR(face_info.facesets[i].size);
-	TEST_FREE_AND_CLEAR(face_info.facesets[i].extension);
-	TEST_FREE_AND_CLEAR(face_info.facesets[i].comment);
+	FREE_AND_CLEAR(face_info.facesets[i].size);
+	FREE_AND_CLEAR(face_info.facesets[i].extension);
+	FREE_AND_CLEAR(face_info.facesets[i].comment);
     }
     reset_player_data();
     for (i=0; i<MAX_SKILL; i++)
-	skill_names[i] = NULL;
+        FREE_AND_CLEAR(skill_names[i]);
 
 }
