@@ -1,9 +1,9 @@
 const char *rcsid_common_misc_c =
-    "$Id: misc.c,v 1.14 2006/02/23 20:18:28 akirschbaum Exp $";
+    "$Id: misc.c 4963 2006-09-21 05:50:22Z mwedel $";
 /*
     Crossfire client, a client program for the crossfire program.
 
-    Copyright (C) 2001 Mark Wedel & Crossfire Development Team
+    Copyright (C) 2006,2001 Mark Wedel & Crossfire Development Team
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@ const char *rcsid_common_misc_c =
 
 /*
  * static char *rcsid_misc_c =
- *   "$Id: misc.c,v 1.14 2006/02/23 20:18:28 akirschbaum Exp $";
+ *   "$Id: misc.c 4963 2006-09-21 05:50:22Z mwedel $";
  */
 
 
@@ -168,11 +168,10 @@ char *getLogText(const LogEntry *le) {
  *
  * See client.h for possible logLevels.
  */
-#ifdef DEBUG
-#define MINLOG 0
-#else
-#define MINLOG 1
-#endif
+int MINLOG=MINLOGLEVEL;
+
+
+
 void LOG(LogLevel level, const char *origin, const char *format, ...)
 {
 
