@@ -1,5 +1,5 @@
 const char *rcsid_common_newsocket_c =
-    "$Id: newsocket.c,v 1.15 2006/05/21 10:32:55 akirschbaum Exp $";
+    "$Id: newsocket.c 5010 2006-10-07 18:29:47Z qal21 $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -28,6 +28,9 @@ const char *rcsid_common_newsocket_c =
  */
 
 
+#ifdef WIN32
+#include <windows.h>
+#endif
 #include <stdio.h>
 #include <stdarg.h>
 #include <errno.h>
@@ -88,7 +91,7 @@ static int write_socket(int fd, const unsigned char *buf, int len)
 
 
 
-void SockList_Init(SockList *sl, char *buf)
+void SockList_Init(SockList *sl, uint8 *buf)
 {
     sl->len=0;
     sl->buf=buf + 2;	/* reserve two bytes for total length */
@@ -260,14 +263,14 @@ int cs_print_string(int fd, const char *str, ...)
 {
     va_list args;
     SockList sl;
-    char buf[MAX_BUF];
+    uint8 buf[MAX_BUF];
 
     SockList_Init(&sl, buf);
     va_start(args, str);
-    sl.len += vsprintf(sl.buf + sl.len, str, args);
+    sl.len += vsprintf((char*)sl.buf + sl.len, str, args);
     va_end(args);
 
-    script_monitor_str(sl.buf);
+    script_monitor_str((char*)sl.buf);
 
     return SockList_Send(&sl, fd);
 }
