@@ -1,5 +1,5 @@
 const char *rcsid_common_player_c =
-    "$Id: player.c,v 1.19 2006/02/23 20:18:28 akirschbaum Exp $";
+    "$Id: player.c 5010 2006-10-07 18:29:47Z qal21 $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -23,6 +23,9 @@ const char *rcsid_common_player_c =
 */
 
  
+#ifdef WIN32
+#include <windows.h>
+#endif
 #include <client.h>
 #include <external.h>
 #include <script.h>
@@ -222,7 +225,7 @@ int send_command(const char *command, int repeat, int must_send) {
 	}
 	else {
 	    SockList sl;
-	    char buf[MAX_BUF];
+	    uint8 buf[MAX_BUF];
 
 	    /* Don't want to copy in administrative commands */
 	    if (!must_send) strcpy(last_command, command);
