@@ -1,5 +1,5 @@
 char *rcsid_gtk2_config_c =
-    "$Id: config.c,v 1.5 2006/05/15 05:57:43 mwedel Exp $";
+    "$Id: config.c 4880 2006-09-04 22:05:09Z mwedel $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -359,7 +359,7 @@ static void setup_config_window()
 	}
 	gtk_tree_model_get(model, &iter, 0, &buf, -1);
 
-	if (!strcasecmp(face_info.want_faceset, buf)) {
+	if (face_info.want_faceset && !strcasecmp(face_info.want_faceset, buf)) {
 	    gtk_combo_box_set_active(GTK_COMBO_BOX(config_combobox_faceset), i);
 	    g_free(buf);
 	    break;
@@ -446,7 +446,7 @@ static void read_config_window()
      * them through its own/different malloc library.
      */
     if (buf) {
-	if (face_info.want_faceset) free(face_info.want_faceset);
+	free(face_info.want_faceset);
 	face_info.want_faceset = strdup_local(buf);
 	g_free(buf);
     }
@@ -555,11 +555,8 @@ on_configure_activate                 (GtkMenuItem     *menuitem,
 
 
 
-void
-on_save_window_position_activate       (GtkMenuItem     *menuitem,
-                                        gpointer         user_data)
+void save_winpos()
 {
-
     char savename[MAX_BUF],buf[MAX_BUF];
     FILE    *save;
     int     x,y,w,h,wx,wy;
@@ -595,6 +592,15 @@ on_save_window_position_activate       (GtkMenuItem     *menuitem,
 
 }
 
+
+void
+on_save_window_position_activate       (GtkMenuItem     *menuitem,
+                                        gpointer         user_data)
+{
+    save_winpos();
+}
+
+
 void load_window_positions(GtkWidget *window_root)
 {
     char loadname[MAX_BUF],buf[MAX_BUF], *cp;
