@@ -1,3 +1,6 @@
+/* about.c */
+extern void menu_about(GtkMenuItem *menuitem, gpointer user_data);
+extern void on_about_close_clicked(GtkButton *button, gpointer user_data);
 /* config.c */
 extern void load_defaults(void);
 extern void save_defaults(void);
@@ -6,6 +9,9 @@ extern void on_config_button_save_clicked(GtkButton *button, gpointer user_data)
 extern void on_config_button_apply_clicked(GtkButton *button, gpointer user_data);
 extern void on_config_button_close_clicked(GtkButton *button, gpointer user_data);
 extern void on_configure_activate(GtkMenuItem *menuitem, gpointer user_data);
+extern void save_winpos(void);
+extern void on_save_window_position_activate(GtkMenuItem *menuitem, gpointer user_data);
+extern void load_window_positions(GtkWidget *window_root);
 /* image.c */
 extern int create_and_rescale_image_from_data(Cache_Entry *ce, int pixmap_num, uint8 *rgba_data, int width, int height);
 extern void addsmooth(uint16 face, uint16 smooth_face);
@@ -71,11 +77,13 @@ extern void reset_keybinding_status(void);
 extern void on_keybinding_button_clear_clicked(GtkButton *button, gpointer user_data);
 /* main.c */
 extern int do_timeout(void);
+extern void client_tick(uint32 tick);
+extern void cleanup_connection(void);
+extern void on_window_destroy_event(GtkObject *object, gpointer user_data);
 extern void do_network(void);
 extern void event_loop(void);
 extern int parse_args(int argc, char **argv);
 extern int main(int argc, char *argv[]);
-extern void save_winpos(void);
 extern void get_window_coord(GtkWidget *win, int *x, int *y, int *wx, int *wy, int *w, int *h);
 /* map.c */
 extern void map_init(GtkWidget *window_root);
@@ -99,7 +107,7 @@ extern gboolean on_drawingarea_magic_map_expose_event(GtkWidget *widget, GdkEven
 extern void on_disconnect_activate(GtkMenuItem *menuitem, gpointer user_data);
 extern void menu_quit_program(GtkMenuItem *menuitem, gpointer user_data);
 extern void menu_quit_character(GtkMenuItem *menuitem, gpointer user_data);
-extern void menu_about(GtkMenuItem *menuitem, gpointer user_data);
+extern void enable_menu_items(int enable);
 /* metaserver.c */
 extern gboolean metaserver_selection_func(GtkTreeSelection *selection, GtkTreeModel *model, GtkTreePath *path, gboolean path_currently_selected, gpointer userdata);
 extern char *get_metaserver(void);
@@ -107,7 +115,9 @@ extern void on_metaserver_select_clicked(GtkButton *button, gpointer user_data);
 extern void on_treeview_metaserver_row_activated(GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *column, gpointer user_data);
 extern void on_metaserver_text_entry_activate(GtkEntry *entry, gpointer user_data);
 extern void on_button_metaserver_quit_pressed(GtkButton *button, gpointer user_data);
+extern gboolean on_metaserver_text_entry_key_press_event(GtkWidget *widget, GdkEventKey *event, gpointer user_data);
 /* opengl.c */
+extern void init_glx_opengl(GtkWidget *drawingarea);
 extern void init_opengl(GtkWidget *drawingarea);
 extern void opengl_gen_map(int redraw);
 extern void create_opengl_map_image(uint8 *data, PixmapInfo *pi);
@@ -132,6 +142,8 @@ extern void on_menu_magical_items_activate(GtkMenuItem *menuitem, gpointer user_
 extern void on_menu_potions_activate(GtkMenuItem *menuitem, gpointer user_data);
 extern void on_menu_valuables_activate(GtkMenuItem *menuitem, gpointer user_data);
 extern void on_menu_wands_rods_horns_activate(GtkMenuItem *menuitem, gpointer user_data);
+extern void on_menu_jewels_activate(GtkMenuItem *menuitem, gpointer user_data);
+extern void on_menu_flesh_activate(GtkMenuItem *menuitem, gpointer user_data);
 extern void on_menu_not_cursed_activate(GtkMenuItem *menuitem, gpointer user_data);
 extern void on_menu_all_weapons_activate(GtkMenuItem *menuitem, gpointer user_data);
 extern void on_menu_missile_weapons_activate(GtkMenuItem *menuitem, gpointer user_data);
@@ -172,7 +184,7 @@ extern void on_spell_invoke_clicked(GtkButton *button, gpointer user_data);
 extern void on_spell_close_clicked(GtkButton *button, gpointer user_data);
 /* stats.c */
 extern void stats_init(GtkWidget *window_root);
-extern void update_stat(int stat_no, int max_stat, int current_stat, const char *name);
+extern void update_stat(int stat_no, int max_stat, int current_stat, const char *name, int can_alert);
 extern void draw_message_window(int redraw);
 extern void draw_stats(int redraw);
 extern void clear_stat_mapping(void);
