@@ -1,5 +1,5 @@
 char *rcsid_gtk2_image_c =
-    "$Id: image.c,v 1.7 2005/12/12 02:54:32 mwedel Exp $";
+    "$Id: image.c 5010 2006-10-07 18:29:47Z qal21 $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -105,6 +105,7 @@ static int icon_rescale_factor[MAX_ICON_SPACES] = {
 
 char facecachedir[MAX_BUF];
 
+/* Does not appear to be used anywhere
 typedef struct Keys {
     uint8	flags;
     sint8	direction;
@@ -112,7 +113,7 @@ typedef struct Keys {
     char	*command;
     struct Keys	*next;
 } Key_Entry;
-
+*/
 
 /* Rotate right from bsd sum. */
 #define ROTATE_RIGHT(c) if ((c) & 01) (c) = ((c) >>1) + 0x80000000; else (c) >>= 1;
@@ -160,7 +161,7 @@ static void create_map_image(uint8 *data, PixmapInfo *pi)
 	    g = ( *l +  *(l+1) + *(l+2)) / 3;
 #endif
 	    p = (uint32*) fog->pixels + i;
-	    *(uint32*) p = g | (g << 8) | (g << 16) | (*(l + 3) << 24);
+	    *p = g | (g << 8) | (g << 16) | (*(l + 3) << 24);
 	}
 
 	SDL_UnlockSurface(fog);
@@ -190,18 +191,20 @@ static void create_map_image(uint8 *data, PixmapInfo *pi)
 	    g = ( *l +  *(l+1) + *(l+2)) / 3;
 #endif
 	    p = (uint32*) fog->pixels + i;
-	    *(uint32*) p = (g << 8) | (g << 16) | (g << 24) | *(l + 3);
+	    *p = (g << 8) | (g << 16) | (g << 24) | *(l + 3);
 	}
 
 	for (i=0; i < pi->map_width * pi->map_height; i+= 4) {
+	    uint32 *tmp;
+
 	    /* The pointer arithemtic below looks suspicious, but it is a patch that
 	     * is submitted, so just putting it in as submitted.
 	     * MSW 2004-05-11
 	     */
 	    p = (uint32*) (fog->pixels + i);
 	    g = ( ((*p >> 24) & 0xff)  + ((*p >> 16) & 0xff) + ((*p >> 8) & 0xff)) / 3;
-            l = (uint32*) fog->pixels + i;
-	    *(uint32*) l = (g << 24) | (g << 16) | (g << 8) | (*p & 0xff);
+            tmp = (uint32*) fog->pixels + i;
+	    *tmp = (g << 24) | (g << 16) | (g << 8) | (*p & 0xff);
 	}
 
 	SDL_UnlockSurface(fog);
