@@ -1,5 +1,5 @@
 char *rcsid_gtk2_inventory_c =
-    "$Id: inventory.c,v 1.10 2006/03/11 08:42:03 mwedel Exp $";
+    "$Id: inventory.c 5078 2006-11-04 08:39:10Z mwedel $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -118,7 +118,7 @@ Notebook_Info	inv_notebooks[NUM_INV_LISTS] = {
 
 
 enum {
-LIST_NONE, LIST_ICON, LIST_NAME, LIST_WEIGHT, LIST_OBJECT, LIST_BACKGROUND, LIST_TYPE, LIST_NUM_COLUMNS
+LIST_NONE, LIST_ICON, LIST_NAME, LIST_WEIGHT, LIST_OBJECT, LIST_BACKGROUND, LIST_TYPE, LIST_BASENAME, LIST_NUM_COLUMNS
 };
 
 
@@ -185,7 +185,8 @@ static void list_item_action(GdkEventButton *event, item *tmp)
 	    if (env & (ITEM_GROUND | ITEM_IN_CONTAINER)) 
 		dest = cpl.ob->tag;
 	    else if (env == ITEM_INVENTORY && cpl.container &&
-		     get_item_env(cpl.container) == ITEM_INVENTORY) {
+		     (get_item_env(cpl.container) == ITEM_INVENTORY ||
+		      get_item_env(cpl.container) == ITEM_GROUND)) {
 		dest = cpl.container->tag;
 	    } else
 		dest = 0;
@@ -298,8 +299,8 @@ static void setup_list_columns(GtkWidget *treeview)
                                                       "pixbuf", LIST_ICON,
                                                       NULL);
 
+/*    gtk_tree_view_column_set_sizing(column, GTK_TREE_VIEW_COLUMN_FIXED);*/
     gtk_tree_view_column_set_min_width(column, image_size);
-    gtk_tree_view_column_set_sizing(column, GTK_TREE_VIEW_COLUMN_FIXED);
     gtk_tree_view_column_set_sort_column_id(column, LIST_TYPE);
     gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
 
@@ -308,7 +309,8 @@ static void setup_list_columns(GtkWidget *treeview)
                                                       "text", LIST_NAME,
                                                       NULL);
     gtk_tree_view_column_set_expand(column, TRUE);
-    gtk_tree_view_column_set_sort_column_id(column, LIST_NAME);
+    gtk_tree_view_column_set_sort_column_id(column, LIST_BASENAME);
+
     gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
     gtk_tree_view_column_add_attribute(column, renderer, "background-gdk", LIST_BACKGROUND);
     gtk_tree_view_set_expander_column(GTK_TREE_VIEW (treeview), column);
@@ -363,7 +365,8 @@ void inventory_init(GtkWidget *window_root)
 				G_TYPE_STRING,
 				G_TYPE_POINTER,
 				GDK_TYPE_COLOR,
-				G_TYPE_INT);
+				G_TYPE_INT,
+				G_TYPE_STRING);
 
     gtk_tree_view_set_model(GTK_TREE_VIEW(treeview_look), GTK_TREE_MODEL(store_look));
     setup_list_columns(treeview_look);
@@ -398,7 +401,8 @@ void inventory_init(GtkWidget *window_root)
 				G_TYPE_STRING,
 				G_TYPE_POINTER,
 				GDK_TYPE_COLOR,
-				G_TYPE_INT);
+				G_TYPE_INT,
+				G_TYPE_STRING);
 	    inv_notebooks[i].treeview = gtk_tree_view_new_with_model(GTK_TREE_MODEL(
 						    inv_notebooks[i].treestore));
 
@@ -565,6 +569,7 @@ static void add_object_to_store(item *it, GtkTreeStore *store,
 		LIST_BACKGROUND, &root_color[bg],
 		LIST_OBJECT, it,
 		LIST_TYPE, it->type,
+		LIST_BASENAME, it->s_name,
                 -1);
 }
 
@@ -852,8 +857,6 @@ void draw_inv(int tab)
 {
     char buf[256];
 
-    if (cpl.ob->inv == NULL) return;
-
     sprintf(buf,"%6.1f/%6.1f", cpl.ob->weight, weight_limit);
     gtk_label_set(GTK_LABEL(weight_label), buf);
 
@@ -878,7 +881,7 @@ void draw_lists ()
 	cpl.container->env->inv_updated = 1;
 	cpl.container->inv_updated=0;
     }
-    if (cpl.ob->inv && cpl.ob->inv_updated) {
+    if (cpl.ob->inv_updated) {
 	draw_inv(gtk_notebook_get_current_page(GTK_NOTEBOOK(inv_notebook)));
 	cpl.ob->inv_updated=0;
     }
