@@ -1,5 +1,5 @@
 char *rcsid_gtk2_keys_c =
-    "$Id: keys.c,v 1.7 2006/03/04 15:56:33 akirschbaum Exp $";
+    "$Id: keys.c 5010 2006-10-07 18:29:47Z qal21 $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -68,8 +68,9 @@ static GtkWidget *fire_label, *run_label, *keybinding_window, *keybinding_checkb
 static GtkListStore    *keybinding_store;
 static GtkTreeSelection  *keybinding_selection;
 
+/* Changed to KLIST_* to avoid conflicts in Win2000 and up */
 enum {
-    LIST_ENTRY, LIST_KEY, LIST_MODS, LIST_EDIT, LIST_COMMAND, LIST_KEY_ENTRY
+    KLIST_ENTRY, KLIST_KEY, KLIST_MODS, KLIST_EDIT, KLIST_COMMAND, KLIST_KEY_ENTRY
 };
 
 GtkWidget *spinbutton_count;
@@ -320,10 +321,11 @@ static void parse_keybind_line(char *buf, int line, int standard)
 
 	/* Rest of the line is the actual command.  Lets kill the newline */
 	cpnext[strlen(cpnext)-1]='\0';
-    if (strlen(cpnext)>(sizeof(bind_buf)-1)){
-        cpnext[sizeof(bind_buf)-1]='\0';
-        LOG(LOG_WARNING,"gtk::parse_keybind_line","Had to truncate a too long command");
-    }
+	if (strlen(cpnext)>(sizeof(bind_buf)-1)){
+	    cpnext[sizeof(bind_buf)-1]='\0';
+	    LOG(LOG_WARNING,"gtk::parse_keybind_line","Had to truncate a too long command");
+	}
+
 	insert_key(keysym, flags | standard, cpnext);
     } /* else if not special binding line */
 }
@@ -436,30 +438,30 @@ void keys_init(GtkWidget *window_root)
 
     renderer = gtk_cell_renderer_text_new ();
     column = gtk_tree_view_column_new_with_attributes ("Key", renderer,
-                                                      "text", LIST_KEY,
+                                                      "text", KLIST_KEY,
                                                       NULL);
-    gtk_tree_view_column_set_sort_column_id(column, LIST_KEY);
+    gtk_tree_view_column_set_sort_column_id(column, KLIST_KEY);
     gtk_tree_view_append_column (GTK_TREE_VIEW (keybinding_treeview), column);
 
     renderer = gtk_cell_renderer_text_new ();
     column = gtk_tree_view_column_new_with_attributes ("Modifiers", renderer,
-                                                      "text", LIST_MODS,
+                                                      "text", KLIST_MODS,
                                                       NULL);
-    gtk_tree_view_column_set_sort_column_id(column, LIST_MODS);
+    gtk_tree_view_column_set_sort_column_id(column, KLIST_MODS);
     gtk_tree_view_append_column (GTK_TREE_VIEW (keybinding_treeview), column);
 
     renderer = gtk_cell_renderer_text_new ();
     column = gtk_tree_view_column_new_with_attributes ("Edit Mode", renderer,
-                                                      "text", LIST_EDIT,
+                                                      "text", KLIST_EDIT,
                                                       NULL);
-    gtk_tree_view_column_set_sort_column_id(column, LIST_EDIT);
+    gtk_tree_view_column_set_sort_column_id(column, KLIST_EDIT);
     gtk_tree_view_append_column (GTK_TREE_VIEW (keybinding_treeview), column);
 
     renderer = gtk_cell_renderer_text_new ();
     column = gtk_tree_view_column_new_with_attributes ("Command", renderer,
-                                                      "text", LIST_COMMAND,
+                                                      "text", KLIST_COMMAND,
                                                       NULL);
-    gtk_tree_view_column_set_sort_column_id(column, LIST_COMMAND);
+    gtk_tree_view_column_set_sort_column_id(column, KLIST_COMMAND);
     gtk_tree_view_append_column (GTK_TREE_VIEW (keybinding_treeview), column);
 
 
@@ -468,7 +470,7 @@ void keys_init(GtkWidget *window_root)
     gtk_tree_selection_set_select_function(keybinding_selection, keybinding_selection_func, NULL, NULL);
 
     gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(keybinding_store),
-                                             LIST_KEY,
+                                             KLIST_KEY,
                                              GTK_SORT_ASCENDING);
 
 
@@ -546,7 +548,7 @@ static void parse_key(char key, uint32 keysym)
 {
     Key_Entry *keyentry, *first_match=NULL;
     int present_flags=0;
-    char buf[MAX_BUF];
+    char buf[MAX_BUF], tmpbuf[MAX_BUF];
 
     if (keysym==commandkeysym) {
 	gtk_widget_grab_focus (GTK_WIDGET(entry_commands));
@@ -635,10 +637,14 @@ static void parse_key(char key, uint32 keysym)
         gtk_spin_button_set_value (GTK_SPIN_BUTTON(spinbutton_count), (float) cpl.count );
 	return;
     }
-    sprintf(buf, "Key unused (%s%s%s)",
-          (cpl.fire_on? "Fire&": ""),
-          (cpl.run_on ? "Run&" : ""),
-          keysym==NoSymbol? "unknown": gdk_keyval_name(keysym));
+    tmpbuf[0]=0;
+    if (cpl.fire_on) strcat(tmpbuf,"fire+");
+    if (cpl.run_on) strcat(tmpbuf,"run+");
+    if (cpl.alt_on) strcat(tmpbuf,"alt+");
+    if (cpl.meta_on) strcat(tmpbuf,"meta+");
+
+    sprintf(buf, "Key %s%s is not bound to any command.  Use bind to associate this keypress with a command",
+	    tmpbuf, keysym==NoSymbol? "unknown": gdk_keyval_name(keysym));
 #ifdef WIN32
        if ( ( 65513 != keysym ) && ( 65511 != keysym ) )
 #endif
@@ -907,8 +913,8 @@ void bind_key(char *params)
 
     if (strlen(params) >= sizeof(bind_buf)) {
 	params[sizeof(bind_buf) - 1] = '\0';
-    draw_info("Keybinding too long! Truncated:",NDI_RED);
-    draw_info(params,NDI_RED);
+	draw_info("Keybinding too long! Truncated:",NDI_RED);
+	draw_info(params,NDI_RED);
     }
     sprintf(buf, "Push key to bind '%s'.", params);
     draw_info(buf,NDI_BLACK);
@@ -1019,6 +1025,7 @@ static void save_keys(void)
 static void configure_keys(uint32 keysym)
 {
     char buf[MAX_BUF];
+    Key_Entry *keyentry, *first_match=NULL;
 
     /* I think that basically if we are not rebinding the special
      * control keys (in which case bind_kesym would be set to something)
@@ -1064,6 +1071,27 @@ static void configure_keys(uint32 keysym)
         bind_keysym=NULL;
     }
     else {
+	keyentry = keys[keysym % KEYHASH];
+	while (keyentry!=NULL) {
+	    if ((keyentry->keysym!=0 && keyentry->keysym!=keysym) ||
+		(!(keyentry->flags & bind_flags))) {
+		    keyentry=keyentry->next;
+		    continue;
+	    }
+	    first_match = keyentry;
+
+	    /* Try to find a prefect match */
+	    if ((keyentry->flags & KEYF_MODIFIERS)!= bind_flags) {
+		keyentry=keyentry->next;
+		continue;
+	    }
+	    else break;
+	}
+	if (first_match) {
+	    sprintf(buf, "Warning: Keybind %s may conflict with new binding.", first_match->command);
+	    draw_info(buf,NDI_RED);
+	}
+
 	insert_key(keysym, bind_flags, bind_buf);
     }
 
@@ -1158,7 +1186,7 @@ unbinded:
     sprintf(buf,"Removed binding: %3d %s", count, get_key_info(key,0));
 
     draw_info(buf,NDI_BLACK);
-    if (key->command) free(key->command);
+    free(key->command);
     free(key);
     save_keys();
 }
@@ -1401,7 +1429,7 @@ on_entry_commands_activate             (GtkEntry        *entry,
                                         gpointer         user_data)
 {
     const gchar *entry_text;
-    extern GtkWidget *textview_info1;
+    extern GtkWidget *treeview_look;
 
     /* Next reply will reset this as necessary */
     if (!use_config[CONFIG_POPUPS])
@@ -1439,7 +1467,7 @@ on_entry_commands_activate             (GtkEntry        *entry,
      * it doesn't make much difference what widget this is set
      * to, as long as it is something that can get focus.
      */
-    gtk_widget_grab_focus (GTK_WIDGET(textview_info1));
+    gtk_widget_grab_focus (GTK_WIDGET(treeview_look));
 
     if( cpl.input_state == Metaserver_Select)
     {
@@ -1481,12 +1509,12 @@ void update_keybinding_list()
 	    if (key->flags & KEYF_STANDARD)  strcat(modifier_buf,"(Standard) ");
 	    gtk_list_store_append(keybinding_store, &iter);
 	    gtk_list_store_set(keybinding_store, &iter,
-			       LIST_ENTRY, i,
-			       LIST_KEY,  gdk_keyval_name(key->keysym),
-			       LIST_MODS, modifier_buf,
-			       LIST_EDIT, (key->flags & KEYF_EDIT) ? "Yes":"No",
-			       LIST_COMMAND, key->command,
-			       LIST_KEY_ENTRY, key,
+                               KLIST_ENTRY, i,
+                               KLIST_KEY,  gdk_keyval_name(key->keysym),
+                               KLIST_MODS, modifier_buf,
+                               KLIST_EDIT, (key->flags & KEYF_EDIT) ? "Yes":"No",
+                               KLIST_COMMAND, key->command,
+                               KLIST_KEY_ENTRY, key,
 			       -1);
 	}
     }
@@ -1562,7 +1590,7 @@ on_keybinding_button_remove_clicked    (GtkButton       *button,
 	LOG(LOG_ERROR,"keys.c:on_keybinding_button_remove_clicked", "Function called with nothing selected\n");
 	return;
     }
-    gtk_tree_model_get(model, &iter, LIST_KEY_ENTRY, &entry, -1);
+    gtk_tree_model_get(model, &iter, KLIST_KEY_ENTRY, &entry, -1);
     for (onkey=0; onkey<KEYHASH; onkey++) {
         for (key=keys[onkey]; key; key =key->next) {
 	    if (key == entry) {
@@ -1589,7 +1617,7 @@ on_keybinding_button_remove_clicked    (GtkButton       *button,
     LOG(LOG_ERROR,"keys.c:on_keybinding_button_remove_clicked", "Unable to find matching key entry\n");
 
 unbinded:
-    if (key->command) free(key->command);
+    free(key->command);
     free(key);
     save_keys();
     update_keybinding_list();
@@ -1681,13 +1709,13 @@ on_keybinding_button_update_clicked    (GtkButton       *button,
     const char *buf;
 
     if (gtk_tree_selection_get_selected (keybinding_selection, &model, &iter)) {
-        gtk_tree_model_get(model, &iter, LIST_KEY_ENTRY, &entry, -1);
+        gtk_tree_model_get(model, &iter, KLIST_KEY_ENTRY, &entry, -1);
 
         if (!entry) {
             LOG(LOG_ERROR,"keys.c:on_keybinding_button_update_clicked", "Unable to get key_entry structure\n");
             return;
 	}
-	if (entry->command) free(entry->command);
+	free(entry->command);
 	keybinding_get_data(&entry->keysym, &entry->flags, &buf);
 	entry->command = strdup_local(buf);
 	update_keybinding_list();
@@ -1727,7 +1755,7 @@ gboolean keybinding_selection_func (
 
     if (gtk_tree_model_get_iter(model, &iter, path)) {
 
-        gtk_tree_model_get(model, &iter, LIST_KEY_ENTRY, &entry, -1);
+        gtk_tree_model_get(model, &iter, KLIST_KEY_ENTRY, &entry, -1);
 
         if (!entry) {
             LOG(LOG_ERROR,"keys.c:keybinding_selection_func", "Unable to get key_entry structure\n");
