@@ -1,5 +1,5 @@
 char *rcsid_gtk2_metaserver_c =
-    "$Id: metaserver.c,v 1.4 2006/02/23 08:30:25 mwedel Exp $";
+    "$Id: metaserver.c 4889 2006-09-06 07:27:06Z mwedel $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -37,7 +37,8 @@ char *rcsid_gtk2_metaserver_c =
 #include "metaserver.h"
 #include "main.h"
 
-static GtkWidget *metaserver_window, *treeview_metaserver, *metaserver_button, *metaserver_status;
+static GtkWidget *metaserver_window, *treeview_metaserver, *metaserver_button,
+    *metaserver_status, *metaserver_entry;
 static GtkListStore    *store_metaserver;
 static GtkTreeSelection  *metaserver_selection;
 
@@ -53,6 +54,8 @@ gboolean metaserver_selection_func (
                       gpointer          userdata)
 {
     gtk_widget_set_sensitive(metaserver_button, TRUE);
+    gtk_entry_set_text(GTK_ENTRY(metaserver_entry), "");
+
     return TRUE;
 }
 
@@ -60,7 +63,8 @@ char *get_metaserver()
 {
     static int has_init=0;
     GtkTreeIter iter;
-    int i;
+    int i, j;
+    const gchar *metaserver_txt;
 
     if (!has_init) {
 	GtkTreeViewColumn *column;
@@ -73,6 +77,7 @@ char *get_metaserver()
 	treeview_metaserver = lookup_widget(metaserver_window, "treeview_metaserver");
 	metaserver_button = lookup_widget(metaserver_window, "metaserver_select");
 	metaserver_status = lookup_widget(metaserver_window, "metaserver_status");
+	metaserver_entry = lookup_widget(metaserver_window, "metaserver_text_entry");
 
 	store_metaserver = gtk_list_store_new (6,
                                 G_TYPE_STRING,
@@ -135,18 +140,30 @@ char *get_metaserver()
     gtk_widget_show(metaserver_window);
 
     gtk_label_set_text(GTK_LABEL(metaserver_status), "Waiting for user selection");
-    gtk_widget_set_sensitive(metaserver_button, FALSE);
+
+    metaserver_txt = gtk_entry_get_text(GTK_ENTRY(metaserver_entry));
+    if (*metaserver_txt == '\0') {
+	gtk_widget_set_sensitive(metaserver_button, FALSE);
+    } else {
+	gtk_widget_set_sensitive(metaserver_button, TRUE);
+    }
 
     gtk_list_store_clear(store_metaserver);
 
     if (cached_servers_num) {
         for ( i = 0; i < cached_servers_num; i++ ) {
-	    gtk_list_store_append(store_metaserver, &iter);
-	    gtk_list_store_set(store_metaserver, &iter, 
+	    for (j=0; j < meta_numservers; j++) {
+		if (!strcmp(cached_servers_name[i], meta_servers[j].hostname))
+		    break;
+	    }
+	    if (j == meta_numservers) {
+		gtk_list_store_append(store_metaserver, &iter);
+		gtk_list_store_set(store_metaserver, &iter, 
 			       LIST_HOSTNAME, cached_servers_name[i],
 			       LIST_IPADDR, cached_servers_ip[i],
 			       LIST_COMMENT, "Cached server entry",
 			       -1);
+	    }
 	}
     }
 
@@ -161,17 +178,23 @@ char *get_metaserver()
 			       LIST_COMMENT, meta_servers[i].comment,
 			       -1);
     }
-    gtk_list_store_append(store_metaserver, &iter);
-    gtk_list_store_set(store_metaserver, &iter, 
+    if (server) {
+	gtk_list_store_append(store_metaserver, &iter);
+	gtk_list_store_set(store_metaserver, &iter, 
 			       LIST_HOSTNAME, server,
 			       LIST_COMMENT, "default server",
 			       -1);
+    }
 
     cpl.input_state = Metaserver_Select;
 
+    enable_menu_items(FALSE);
+    /* draw_map() is to just redraw the splash */
+    draw_map(FALSE);
     gtk_main();
 
     gtk_widget_hide(metaserver_window);
+    enable_menu_items(TRUE);
     return cpl.input_text;
 }
 
@@ -182,31 +205,42 @@ on_metaserver_select_clicked           (GtkButton       *button,
 {
     GtkTreeModel    *model;
     GtkTreeIter iter;
-    char    *name, *ip, buf[256];
+    char    *name=NULL, *ip=NULL, buf[256], *metaserver_txt;
 
+    metaserver_txt = (char*)gtk_entry_get_text(GTK_ENTRY(metaserver_entry));
     if (gtk_tree_selection_get_selected (metaserver_selection, &model, &iter)) {
 	gtk_tree_model_get(model, &iter, LIST_HOSTNAME, &name, LIST_IPADDR, &ip, -1);
 
-	snprintf(buf, 255, "Trying to connect to %s", name);
+    } else if (*metaserver_txt == '\0') {
 
-	gtk_label_set_text(GTK_LABEL(metaserver_status), buf);
-
-	csocket.fd=init_connection(ip?ip:name, use_config[CONFIG_PORT]);
-	if (csocket.fd==-1) {
-	    snprintf(buf, 255, "Unable to connect to %s!", name);
-	    gtk_label_set_text(GTK_LABEL(metaserver_status), buf);
-	} else {
-	    snprintf(buf, 255, "Connected to %s!", name);
-	    gtk_label_set_text(GTK_LABEL(metaserver_status), buf);
-	    gtk_main_quit();
-	    cpl.input_state = Playing;
-	}
+        /* This can happen if user blanks out server name text field then hits
+         * the connect button.
+         */
+        gtk_label_set_text(GTK_LABEL(metaserver_status), "Error - nothing selected!\n");
+	gtk_widget_set_sensitive(metaserver_button, FALSE);
+        return;
     } else {
 	/* This shouldn't happen because the button shouldn't be pressable
 	 * until the user selects something
 	 */
 	gtk_label_set_text(GTK_LABEL(metaserver_status), "Error - nothing selected!\n");
     }
+    if (!name) name = metaserver_txt;
+
+    snprintf(buf, 255, "Trying to connect to %s", name);
+
+    gtk_label_set_text(GTK_LABEL(metaserver_status), buf);
+
+    csocket.fd=init_connection(ip?ip:name, use_config[CONFIG_PORT]);
+    if (csocket.fd==-1) {
+	snprintf(buf, 255, "Unable to connect to %s!", name);
+	gtk_label_set_text(GTK_LABEL(metaserver_status), buf);
+    } else {
+	snprintf(buf, 255, "Connected to %s!", name);
+	gtk_label_set_text(GTK_LABEL(metaserver_status), buf);
+	gtk_main_quit();
+	cpl.input_state = Playing;
+    }
 }
 
 
@@ -273,3 +307,15 @@ on_button_metaserver_quit_pressed      (GtkButton       *button,
 
 }
 
+gboolean
+on_metaserver_text_entry_key_press_event
+                                        (GtkWidget       *widget,
+                                        GdkEventKey     *event,
+                                        gpointer         user_data)
+{
+
+    gtk_widget_set_sensitive(metaserver_button, TRUE);
+    gtk_tree_selection_unselect_all(metaserver_selection);
+    return FALSE;
+}
+
