@@ -1,5 +1,5 @@
 char *rcsid_gtk_pickup_c =
-    "$Id: pickup.c,v 1.2 2005/11/01 13:46:10 akirschbaum Exp $";
+    "$Id: pickup.c 5145 2006-11-29 22:55:31Z ryo_saeba $";
 
 /*
     Crossfire client, a client program for the crossfire program.
@@ -81,6 +81,8 @@ char *rcsid_gtk_pickup_c =
 #define PU_MAGIC_DEVICE		0x00800000
 
 #define PU_NOT_CURSED		0x01000000
+#define PU_JEWELS		0x02000000
+#define PU_FLESH		0x04000000
 
 static unsigned int pmode=0;
 
@@ -267,6 +269,22 @@ on_menu_not_cursed_activate            (GtkMenuItem     *menuitem,
 
 }
 
+void
+on_menu_jewels_activate                  (GtkMenuItem     *menuitem,
+                                        gpointer         user_data)
+{
+    new_menu_pickup(gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(menuitem)), PU_JEWELS);
+
+}
+
+void
+on_menu_flesh_activate                  (GtkMenuItem     *menuitem,
+                                        gpointer         user_data)
+{
+    new_menu_pickup(gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(menuitem)), PU_FLESH);
+
+}
+
 /***************************************************************************
  * Weapons submenu
  ***************************************************************************/
