@@ -1,5 +1,5 @@
 char *rcsid_gtk2_png_c =
-    "$Id: png.c,v 1.3 2005/05/29 16:25:45 tchize Exp $";
+    "$Id: png.c 5010 2006-10-07 18:29:47Z qal21 $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -68,7 +68,7 @@ uint8 *png_to_data(uint8 *data, int len, uint32 *width, uint32 *height)
 
     png_structp	png_ptr;
     png_infop	info_ptr;
-    int bit_depth, color_type, interlace_type, compression_type, filter_type, y;
+    int bit_depth, color_type, interlace_type, compression_type, y;
 
     data_len=len;
     data_cp = data;
@@ -661,8 +661,8 @@ int png_to_gdkpixmap(GdkWindow *window, uint8 *data, int len,
 	has_alpha=1;
     }
     else {
-	*mask = None;
-	gc_alpha = None;    /* Prevent compile warnings */
+        *mask = NULL;
+        gc_alpha = NULL;    /* Prevent compile warnings */
     }
     i=0;
     for (y=0; y<height; y++) {
