@@ -1,5 +1,5 @@
 const char *rcsid_gtk_config_c =
-    "$Id: config.c,v 1.31 2006/02/28 08:09:52 mwedel Exp $";
+    "$Id: config.c 4963 2006-09-21 05:50:22Z mwedel $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -261,7 +261,7 @@ static void applyconfig(void) {
     int onbutton;
     int lighting = 0;
 
-    if (face_info.want_faceset) free(face_info.want_faceset);
+    free(face_info.want_faceset);
     face_info.want_faceset = strdup_local(gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(faceset_combo)->entry)));
     for (onbutton =0; onbutton < MAX_BUTTONS; onbutton++) {
 	if (cbuttons[onbutton].type == CBUTTON) {
@@ -398,7 +398,7 @@ void configdialog(GtkWidget *widget) {
     GList	*flist;
     int i, num_extras=0;
 
-    const gchar *titles[] ={"#","Key","(#)","Mods","Command"};	   
+    gchar *titles[] ={"#","Key","(#)","Mods","Command"};	   
 
     /* If the window isnt already up (in which case it's just raised) */
     if(!gtkwin_config) {
