@@ -1,5 +1,5 @@
 const char *rcsid_gtk_image_c =
-    "$Id: image.c,v 1.27 2006/02/23 20:18:28 akirschbaum Exp $";
+    "$Id: image.c 5086 2006-11-06 05:49:27Z mwedel $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -158,7 +158,7 @@ static void create_map_image(uint8 *data, PixmapInfo *pi)
              */
             g=(77*(*l)+151*(*(l+1))+28*(*(l+2)))>>8;
 	    p = (uint32*) fog->pixels + i;
-	    *(uint32*) p = g | (g << 8) | (g << 16) | (*(l + 3) << 24);
+	    *p = g | (g << 8) | (g << 16) | (*(l + 3) << 24);
 	}
 
 	SDL_UnlockSurface(fog);
@@ -193,18 +193,20 @@ static void create_map_image(uint8 *data, PixmapInfo *pi)
              */
             g=(77*(*l)+151*(*(l+1))+28*(*(l+2)))>>8;
 	    p = (uint32*) fog->pixels + i;
-	    *(uint32*) p = (g << 8) | (g << 16) | (g << 24) | *(l + 3);
+	    *p = (g << 8) | (g << 16) | (g << 24) | *(l + 3);
 	}
 
 	for (i=0; i < pi->map_width * pi->map_height; i+= 4) {
+	    uint32 *tmp;
+
 	    /* The pointer arithemtic below looks suspicious, but it is a patch that
 	     * is submitted, so just putting it in as submitted.
 	     * MSW 2004-05-11
 	     */
 	    p = (uint32*) (fog->pixels + i);
 	    g = ( ((*p >> 24) & 0xff)  + ((*p >> 16) & 0xff) + ((*p >> 8) & 0xff)) / 3;
-            l = (uint32*) fog->pixels + i;
- 	    *(uint32*) l = (g << 24) | (g << 16) | (g << 8) | (*p & 0xff);
+            tmp = (uint32*) fog->pixels + i;
+ 	    *tmp = (g << 24) | (g << 16) | (g << 8) | (*p & 0xff);
 
 	}
 
@@ -307,8 +309,12 @@ int create_and_rescale_image_from_data(Cache_Entry *ce, int pixmap_num, uint8 *r
      *  maybe, but it uses graphical resources, and takes time (don't laugh, some people use
      *   slow old comps! :p)
      *  Ryo 2005-09-05
+     *
+     * Maybe, but only if were using PIXMAP mode - otherwise, SDL doesn't know how to
+     * draw GDK pixmaps.
+     * MSW 2006-11-05							
      */
-    if (iscale == use_config[CONFIG_MAPSCALE]) {
+    if (iscale == use_config[CONFIG_MAPSCALE] && use_config[CONFIG_DISPLAYMODE]==CFG_DM_PIXMAP) {
         pi->map_height = pi->icon_height;
         pi->map_width = pi->icon_width;
         pi->map_mask = pi->icon_mask;
