@@ -1,5 +1,5 @@
 const char *rcsid_gtk_keys_c =
-    "$Id: keys.c,v 1.23 2006/03/14 18:08:45 ryo_saeba Exp $";
+    "$Id: keys.c 4963 2006-09-21 05:50:22Z mwedel $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -983,7 +983,7 @@ unbinded:
     sprintf(buf,"Removed binding: %3d %s", count, get_key_info(key,0));
 
     draw_info(buf,NDI_BLACK);
-    if (key->command) free(key->command);
+    free(key->command);
     free(key);
     save_keys();
 }
@@ -1193,16 +1193,22 @@ void bind_callback (GtkWidget *gtklist, GdkEventButton *event) {
 }
 
 void ckeyunbind (GtkWidget *gtklist, GdkEventButton *event) {
-  gchar *buf;
-  GList *node;
-  node =  GTK_CLIST(cclist)->selection;
-  if (node) {
-    gtk_clist_get_text (GTK_CLIST(cclist), (gint)node->data, 0, &buf);
+    gchar *buf;
+    GList *node;
+    node =  GTK_CLIST(cclist)->selection;
 
-    unbind_key(buf);
-    draw_keybindings (cclist);
-
-  }
+    if (node) {
+	/* this line generates an warning about mismatched pointer sizes.  Not sure
+	 * if there is any good fix for it.
+	 * In addition, this appears to be using unsupported logic -
+	 * proper programming logic should not be accessing the clist->selection
+	 * data directly.  Better approach would probably be to catch the selection
+	 * in the clist, then store away what as selected.
+	 */
+	gtk_clist_get_text (GTK_CLIST(cclist), (gint)node->data, 0, &buf);
+	unbind_key(buf);
+	draw_keybindings (cclist);
+    }
 }
 
 void ckeyentry_callback (GtkWidget *widget, GdkEventKey *event, GtkWidget *window) {
