@@ -1,5 +1,5 @@
 const char *rcsid_gtk_png_c =
-    "$Id: png.c,v 1.13 2006/02/23 20:18:28 akirschbaum Exp $";
+    "$Id: png.c 4963 2006-09-21 05:50:22Z mwedel $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -399,8 +399,6 @@ uint8 *rescale_rgba_data(uint8 *data, int *width, int *height, int scale)
 }
 
 
-static guchar rgb[512*512*3];	/* Make this especially big to support larger images in the future */
-
 /* This takes data that has already been converted into RGBA format (via
  * png_to_data above perhaps) and creates a GdkPixmap and GdkBitmap out
  * of it.
@@ -456,218 +454,3 @@ int rgba_to_gdkpixmap(GdkWindow *window, uint8 *data,int width, int height,
 }
 
 
-static int png_to_gdkpixmap(GdkWindow *window, uint8 *data, int len,
-		   GdkPixmap **pix, GdkBitmap **mask, GdkColormap *colormap)
-{
-    static uint8 *pixels=NULL;
-    static int pixels_byte=0, rows_byte=0;
-    static png_bytepp	rows=NULL;
-    unsigned long width, height;
-    png_structp	png_ptr;
-    png_infop	info_ptr;
-    int bit_depth, color_type, interlace_type, compression_type,
-	bpp, x,y,has_alpha,i,alpha;
-    GdkColor  scolor;
-    GdkGC	*gc, *gc_alpha;
-
-    data_len=len;
-    data_cp = data;
-    data_start=0;
-
-    png_ptr = png_create_read_struct(PNG_LIBPNG_VER_STRING,
-				     NULL, NULL, NULL);
-
-    if (!png_ptr) {
-	return PNGX_OUTOFMEM;
-    }
-    info_ptr = png_create_info_struct (png_ptr);
-
-    if (!info_ptr) {
-	png_destroy_read_struct (&png_ptr, NULL, NULL);
-	return PNGX_OUTOFMEM;
-    }
-    if (setjmp (png_ptr->jmpbuf)) {
-	png_destroy_read_struct (&png_ptr, &info_ptr,NULL);
-	return PNGX_DATA;
-    }
-    has_alpha=0;
-    png_set_read_fn(png_ptr, NULL, user_read_data);
-    png_read_info (png_ptr, info_ptr);
-    
-   /*
-    * This seems to bug on at least one system (other than mine)
-    * http://www.metalforge.net/cfmb/viewtopic.php?t=1085
-    *
-    * I think its actually a bug in libpng. This function dies with an 
-    * error based on image width. However I've produced a work around
-    * using the indivial functions. Repeated below.
-    * 
-    png_get_IHDR(png_ptr, info_ptr, &width, &height, &bit_depth,
-		 &color_type, &interlace_type, &compression_type, &filter_type);
-    */
-    width = png_get_image_width(png_ptr, info_ptr);
-    height = png_get_image_height(png_ptr, info_ptr);
-    bit_depth = png_get_bit_depth(png_ptr, info_ptr);
-    color_type = png_get_color_type(png_ptr, info_ptr);
-    interlace_type = png_get_interlace_type(png_ptr, info_ptr);
-    compression_type = png_get_compression_type(png_ptr, info_ptr);
-    if (color_type == PNG_COLOR_TYPE_PALETTE &&
-            bit_depth <= 8) {
-
-                /* Convert indexed images to RGB */
-                png_set_expand (png_ptr);
-
-    } else if (color_type == PNG_COLOR_TYPE_GRAY &&
-                   bit_depth < 8) {
-
-                /* Convert grayscale to RGB */
-                png_set_expand (png_ptr);
-
-    } else if (png_get_valid (png_ptr,
-                                  info_ptr, PNG_INFO_tRNS)) {
-
-                /* If we have transparency header, convert it to alpha
-                   channel */
-                png_set_expand(png_ptr);
-
-    } else if (bit_depth < 8) {
-
-                /* If we have < 8 scale it up to 8 */
-                png_set_expand(png_ptr);
-
-
-                /* Conceivably, png_set_packing() is a better idea;
-                 * God only knows how libpng works
-                 */
-    }
-        /* If we are 16-bit, convert to 8-bit */
-    if (bit_depth == 16) {
-                png_set_strip_16(png_ptr);
-    }
-
-        /* If gray scale, convert to RGB */
-    if (color_type == PNG_COLOR_TYPE_GRAY ||
-            color_type == PNG_COLOR_TYPE_GRAY_ALPHA) {
-                png_set_gray_to_rgb(png_ptr);
-    }
-
-        /* If interlaced, handle that */
-    if (interlace_type != PNG_INTERLACE_NONE) {
-                png_set_interlace_handling(png_ptr);
-    }
-
-    /* Update the info the reflect our transformations */
-    png_read_update_info(png_ptr, info_ptr);
-    /* re-read due to transformations just made */
-    /*
-     * This seems to bug on at least one system (other than mine)
-     * http://www.metalforge.net/cfmb/viewtopic.php?t=1085
-     *
-     * I think its actually a bug in libpng. This function dies with an 
-     * error based on image width. However I've produced a work around
-     * using the indivial functions. Repeated below.
-     *
-    png_get_IHDR(png_ptr, info_ptr, &width, &height, &bit_depth,
-		 &color_type, &interlace_type, &compression_type, &filter_type);
-     */
-    width = png_get_image_width(png_ptr, info_ptr);
-    height = png_get_image_height(png_ptr, info_ptr);
-    bit_depth = png_get_bit_depth(png_ptr, info_ptr);
-    color_type = png_get_color_type(png_ptr, info_ptr);
-    interlace_type = png_get_interlace_type(png_ptr, info_ptr);
-    compression_type = png_get_compression_type(png_ptr, info_ptr);
-    
-    if (color_type & PNG_COLOR_MASK_ALPHA)
-                bpp = 4;
-    else
-                bpp = 3;
-
-    /* Allocate the memory we need once, and increase it if necessary.
-     * This is more efficient the allocating this block of memory every time.
-     */
-    if (pixels_byte==0) {
-	pixels_byte = width * height * bpp;
-	pixels = (uint8*)malloc(pixels_byte);
-    } else if ((width * height * bpp) > pixels_byte) {
-	pixels_byte =width * height * bpp;
-	/* Doing a free/malloc is probably more efficient -
-	 * we don't care about the old data in this
-	 * buffer.
-	 */
-	free(pixels);
-	pixels= (uint8*)malloc(pixels_byte);
-    }
-
-    if (!pixels) {
-	png_destroy_read_struct (&png_ptr, &info_ptr, NULL);
-	pixels_byte=0;
-	return PNGX_OUTOFMEM;
-    }
-    if (rows_byte == 0) {
-	rows =(png_bytepp) malloc(sizeof(char*) * height);
-	rows_byte=height;
-    } else if (height > rows_byte) {
-	rows =(png_bytepp) realloc(rows, sizeof(char*) * height);
-	rows_byte=height;
-    }
-    if (!rows) {
-	png_destroy_read_struct (&png_ptr, &info_ptr, NULL);
-	pixels_byte=0;
-	return PNGX_OUTOFMEM;
-    }
-
-    for (y=0; y<height; y++) 
-	rows[y] = pixels + y * width * bpp;
-
-    png_read_image(png_ptr, rows);
-#if 0
-    fprintf(stderr,"image is %d X %d, bpp=%d, color_type=%d\n",
-	    width, height, bpp, color_type);
-#endif
-
-    *pix = gdk_pixmap_new(window, width, height, -1);
-
-
-    gc=gdk_gc_new(*pix);
-    gdk_gc_set_function(gc, GDK_COPY);
-
-    if (color_type & PNG_COLOR_MASK_ALPHA) {
-	*mask=gdk_pixmap_new(window, width, height,1);
-	gc_alpha=gdk_gc_new(*mask);
-	gdk_gc_set_function(gc_alpha, GDK_COPY);
-
-	scolor.pixel=1;
-	gdk_gc_set_foreground(gc_alpha, &scolor);
-	gdk_draw_rectangle(*mask, gc_alpha, 1, 0, 0, width, height);
-
-	scolor.pixel=0;
-	gdk_gc_set_foreground(gc_alpha, &scolor);
-	has_alpha=1;
-    }
-    else {
-	*mask = None;
-	gc_alpha = None;    /* Prevent compile warnings */
-    }
-    i=0;
-    for (y=0; y<height; y++) {
-	for (x=0; x<width; x++) {
-	    rgb[i++]=rows[y][x*bpp];	/* red */
-	    rgb[i++]=rows[y][x*bpp+1];	/* green */
-	    rgb[i++]=rows[y][x*bpp+2];	/* blue */
-	    if (has_alpha) {
-		alpha = rows[y][x*bpp+3];
-		/* Transparent bit */
-		if (alpha==0) {
-		    gdk_draw_point(*mask, gc_alpha, x, y);
-		}
-	    }
-	}
-    }
-    gdk_draw_rgb_image(*pix, gc,  0, 0, 32, 32, GDK_RGB_DITHER_NONE, rgb, 32*3);
-    png_destroy_read_struct (&png_ptr, &info_ptr, NULL);
-    if (has_alpha)
-	gdk_gc_destroy(gc_alpha);
-    gdk_gc_destroy(gc);
-    return 0;
-}
-
