@@ -1,5 +1,5 @@
 char *rcsid_gtk_text_c =
-    "$Id: text.c,v 1.11 2006/02/23 20:18:28 akirschbaum Exp $";
+    "$Id: text.c 5063 2006-10-29 21:58:01Z ryo_saeba $";
 /*
     Crossfire client, a client program for the crossfire program.
 
@@ -415,8 +415,7 @@ static void book_callback(int flag, int type, int subtype, char *message) {
 static char *last_motd = NULL;
 static void motd_callback(int flag, int type, int subtype, char *message) {
     
-    if(last_motd)
-        free(last_motd);
+    free(last_motd);
     last_motd = malloc(strlen(message)+1);
     if (last_motd==NULL)
         LOG(LOG_ERROR,"gtk::motd_callback","Outa memory, no save of motd");
@@ -427,7 +426,7 @@ static void motd_callback(int flag, int type, int subtype, char *message) {
         write_media(GTK_TEXT(gtkwin_info_text), message);
     }
 }
-static void void_callback(int flag, int type, int subtype, const char *message) {
+static void void_callback(int flag, int type, int subtype, char *message) {
     
     LOG(LOG_INFO,"gtk::void_callback","got message --\n%s\n",message);
     
@@ -481,10 +480,8 @@ static void admin_callback(int flag, int type, int subtype, char *message) {
                     new->title= malloc(strlen(message)+1);
                     new->content=malloc(strlen(str1)+1);
                     if ( (!new->title) || (!new->content)){
-                        if (new->title)
-                            free(new->title);
-                        if (new->content)
-                            free(new->content);
+                        free(new->title);
+                        free(new->content);
                         LOG(LOG_ERROR,"gtk::admin_callback","Outa memory, no save of news");
                         free(new);
                         return;
@@ -499,9 +496,9 @@ static void admin_callback(int flag, int type, int subtype, char *message) {
                 return;
             }
             break;
+
         case MSG_TYPE_ADMIN_RULES:
-            if (rules)
-                free(rules);
+            free(rules);
             rules = malloc(strlen(message)+1);
             if (rules){
                 strcpy(rules,message);
@@ -509,8 +506,9 @@ static void admin_callback(int flag, int type, int subtype, char *message) {
             else
                 LOG(LOG_ERROR,"gtk::admin_callback","Outa memory, no save of rules");
             return;
+
     }
-    show_media_message("Unknown admin message",message);
+    draw_info(message, flag);
 }
 void init_text_callbacks(void) {
     setTextManager(MSG_TYPE_BOOK,book_callback);
@@ -521,19 +519,15 @@ void init_text_callbacks(void) {
 }
 void cleanup_textmanagers(void) {
     news_entry* last_entry;
-    if (last_motd)
-        free(last_motd);
+    free(last_motd);
     last_motd=NULL;
-    if (rules)
-        free(rules);
+    free(rules);
     rules = NULL;
     last_entry= first_news;
     while (last_entry){
         first_news=last_entry->next;
-        if (last_entry->content)
-            free(last_entry->content);
-        if (last_entry->title)
-            free(last_entry->title);
+        free(last_entry->content);
+        free(last_entry->title);
         free(last_entry);
         last_entry=first_news;
     }
